@@ -6,38 +6,38 @@ from newsapi.newsapi_exception import NewsAPIException
 
 class NewsApiClient(object):
 
-    def __init__(self, api_key):
+    def __init__(self, api_key: str):
         self.auth = NewsApiAuth(api_key=api_key)
 
-    def get_top_headlines(self, q=None, sources=None, language=None, country=None, category=None, page_size=None,
-                          page=None):
+    def get_top_headlines(self, q=None: str, sources=None: str, language='en': str, country=None: str, category=None: str, page_size=20: int,
+                          page=None: int) -> dict:
         """
             Returns live top and breaking headlines for a country, specific category in a country, single source, or multiple sources..
-            
+
             Optional parameters:
                 (str) q - return headlines w/ specific keyword or phrase. For example:
                           'bitcoin', 'trump', 'tesla', 'ethereum', etc.
-                            
+
                 (str) sources - return headlines of news sources! some Valid values are:
                                 'bbc-news', 'the-verge', 'abc-news', 'crypto coins news',
                                 'ary news','associated press','wired','aftenposten','australian financial review','axios',
 				'bbc news','bild','blasting news','bloomberg','business insider','engadget','google news',
 				'hacker news','info money,'recode','techcrunch','techradar','the next web','the verge' etc.
-							
+
 		(str) language - The 2-letter ISO-639-1 code of the language you want to get headlines for. Valid values are:
 				 'ar','de','en','es','fr','he','it','nl','no','pt','ru','se','ud','zh'
-                            
+
                 (str) country - The 2-letter ISO 3166-1 code of the country you want to get headlines! Valid values are:
-                                'ae','ar','at','au','be','bg','br','ca','ch','cn','co','cu','cz','de','eg','fr','gb','gr',    									
+                                'ae','ar','at','au','be','bg','br','ca','ch','cn','co','cu','cz','de','eg','fr','gb','gr',
                                 'hk','hu','id','ie','il','in','it','jp','kr','lt','lv','ma','mx','my','ng','nl','no','nz',
                                 'ph','pl','pt','ro','rs','ru','sa','se','sg','si','sk','th','tr','tw','ua','us'
-								
+
 		(str) category - The category you want to get headlines for! Valid values are:
 				 'business','entertainment','general','health','science','sports','technology'
-								
-		(int) page_size - The number of results to return per page (request). 20 is the default, 100 is the maximum. 
-								
-		(int) page - Use this to page through the results if the total results found is greater than the page size.									
+
+		(int) page_size - The number of results to return per page (request). 20 is the default, 100 is the maximum.
+
+		(int) page - Use this to page through the results if the total results found is greater than the page size.
         """
 
         # Define Payload
@@ -48,9 +48,9 @@ class NewsApiClient(object):
             if type(q) == str:
                 payload['q'] = q
             else:
-                raise TypeError('keyword/phrase q param should be a str')
+                raise TypeError('keyword/phrase q param should be of type str')
 
-        # Sources 
+        # Sources
         if (sources is not None) and ((country is not None) or (category is not None)):
             raise ValueError('cannot mix country/category param with sources param.')
 
@@ -59,9 +59,9 @@ class NewsApiClient(object):
             if type(sources) == str:
                 payload['sources'] = sources
             else:
-                raise TypeError('sources param should be a str')
+                raise TypeError('sources param should be of type str')
 
-        # Language 
+        # Language
         if language is not None:
             if type(language) == str:
                 if language in const.languages:
@@ -69,7 +69,7 @@ class NewsApiClient(object):
                 else:
                     raise ValueError('invalid language')
             else:
-                raise TypeError('language param should be a string')
+                raise TypeError('language param should be of type str')
 
         # Country
         if country is not None:
@@ -79,9 +79,9 @@ class NewsApiClient(object):
                 else:
                     raise ValueError('invalid country')
             else:
-                raise TypeError('country param should be a string')
+                raise TypeError('country param should be of type str')
 
-                # Category
+        # Category
         if category is not None:
             if type(category) == str:
                 if category in const.categories:
@@ -89,12 +89,12 @@ class NewsApiClient(object):
                 else:
                     raise ValueError('invalid category')
             else:
-                raise TypeError('category param should be a string')
+                raise TypeError('category param should be of type str')
 
         # Page Size
         if page_size is not None:
             if type(page_size) == int:
-                if page_size >= 0 and page_size <= 100:
+                if 0 <= page_size <= 100:
                     payload['pageSize'] = page_size
                 else:
                     raise ValueError('page_size param should be an int between 1 and 100')
@@ -120,36 +120,39 @@ class NewsApiClient(object):
 
         return r.json()
 
-    def get_everything(self, q=None, sources=None, domains=None, from_param=None, to=None, language=None,
-                       sort_by=None, page=None, page_size=None):
+    def get_everything(self, q=None: str, sources=None: str, domains=None: str, exclude_domains=None: str,
+                       from_param=None: str, to=None: str, language='en': str, sort_by=None: str, page=None: int,
+                       page_size=20: int) -> dict:
         """
             Search through millions of articles from over 5,000 large and small news sources and blogs.
-            
+
             Optional parameters:
                 (str) q - return headlines w/ specified coin! Valid values are:
                             'bitcoin', 'trump', 'tesla', 'ethereum', etc
-                            
+
                 (str) sources - return headlines of news sources! some Valid values are:
                             'bbc-news', 'the-verge', 'abc-news', 'crypto coins news',
                             'ary news','associated press','wired','aftenposten','australian financial review','axios',
 			    'bbc news','bild','blasting news','bloomberg','business insider','engadget','google news',
 		  	    'hacker news','info money,'recode','techcrunch','techradar','the next web','the verge' etc.
-							
-		(str) domains - A comma-seperated string of domains (eg bbc.co.uk, techcrunch.com, engadget.com) to restrict the search to. 
 
-		(str) from_parameter - A date and optional time for the oldest article allowed.
+		(str) domains - A comma-seperated string of domains (eg bbc.co.uk, techcrunch.com, engadget.com) to restrict the search to.
+
+        (str) exclude_domains - A comma_seperated string of domains to be excluded from the search
+
+		(str) from_param - A date and optional time for the oldest article allowed.
                                        (e.g. 2018-03-05 or 2018-03-05T03:46:15)
-				
+
 		(str) to - A date and optional time for the newest article allowed.
-							
+
 		(str) language - The 2-letter ISO-639-1 code of the language you want to get headlines for. Valid values are:
 				'ar','de','en','es','fr','he','it','nl','no','pt','ru','se','ud','zh'
-								
-		(str) sort_by - The order to sort the articles in. Valid values are: 'relevancy','popularity','publishedAt'
-								
-		(int) page_size - The number of results to return per page (request). 20 is the default, 100 is the maximum.		
 
-		(int) page - Use this to page through the results if the total results found is greater than the page size.									
+		(str) sort_by - The order to sort the articles in. Valid values are: 'relevancy','popularity','publishedAt'
+
+		(int) page_size - The number of results to return per page (request). 20 is the default, 100 is the maximum.
+
+		(int) page - Use this to page through the results if the total results found is greater than the page size.
         """
 
         # Define Payload
@@ -160,23 +163,29 @@ class NewsApiClient(object):
             if type(q) == str:
                 payload['q'] = q
             else:
-                raise TypeError('keyword/phrase q param should be a str')
+                raise TypeError('keyword/phrase q param should be of type str')
 
         # Sources
         if sources is not None:
             if type(sources) == str:
                 payload['sources'] = sources
             else:
-                raise TypeError('sources param should be a str')
+                raise TypeError('sources param should be of type str')
 
         # Domains To Search
         if domains is not None:
             if type(domains) == str:
                 payload['domains'] = domains
             else:
-                raise TypeError('domains param should be a string')
+                raise TypeError('domains param should be of type str')
 
-        # Search From This Date ... 
+        if exclude_domains is not None:
+            if isinstance(exclude_domains, str):
+                payload['excludeDomains'] = exclude_domains
+            else:
+                raise TypeError('exclude_domains param should be of type str')
+
+        # Search From This Date ...
         if from_param is not None:
             if type(from_param) == str:
                 if (len(from_param)) >= 10:
@@ -188,9 +197,9 @@ class NewsApiClient(object):
                 else:
                     raise ValueError('from_param should be in the format of YYYY-MM-DD')
             else:
-                raise TypeError('from_param should be a string')
+                raise TypeError('from_param should be of type str')
 
-        # ... To This Date 
+        # ... To This Date
         if to is not None:
             if type(to) == str:
                 if (len(to)) >= 10:
@@ -202,7 +211,7 @@ class NewsApiClient(object):
                 else:
                     raise ValueError('to param should be in the format of YYYY-MM-DD')
             else:
-                raise TypeError('to param should be a string')
+                raise TypeError('to param should be of type str')
 
         # Language
         if language is not None:
@@ -212,7 +221,7 @@ class NewsApiClient(object):
                 else:
                     payload['language'] = language
             else:
-                raise TypeError('language param should be a string')
+                raise TypeError('language param should be of type str')
 
         # Sort Method
         if sort_by is not None:
@@ -222,12 +231,12 @@ class NewsApiClient(object):
                 else:
                     raise ValueError('invalid sort')
             else:
-                raise TypeError('sort_by param should be a string')
+                raise TypeError('sort_by param should be of type str')
 
         # Page Size
         if page_size is not None:
             if type(page_size) == int:
-                if page_size >= 0 and page_size <= 100:
+                if 0 <= page_size <= 100:
                     payload['pageSize'] = page_size
                 else:
                     raise ValueError('page_size param should be an int between 1 and 100')
@@ -253,25 +262,25 @@ class NewsApiClient(object):
 
         return r.json()
 
-    def get_sources(self, category=None, language=None, country=None):
+    def get_sources(self, category=None: str, language='en': str, country=None: str) -> dict:
         """
             Returns the subset of news publishers that top headlines...
-            
+
             Optional parameters:
                 (str) category - The category you want to get headlines for! Valid values are:
 				 'business','entertainment','general','health','science','sports','technology'
-			
+
 		(str) language - The 2-letter ISO-639-1 code of the language you want to get headlines for. Valid values are:
 				'ar','de','en','es','fr','he','it','nl','no','pt','ru','se','ud','zh'
-                            
+
                 (str) country - The 2-letter ISO 3166-1 code of the country you want to get headlines! Valid values are:
-                                'ae','ar','at','au','be','bg','br','ca','ch','cn','co','cu','cz','de','eg','fr','gb','gr',    									
+                                'ae','ar','at','au','be','bg','br','ca','ch','cn','co','cu','cz','de','eg','fr','gb','gr',
                                 'hk','hu','id','ie','il','in','it','jp','kr','lt','lv','ma','mx','my','ng','nl','no','nz',
                                 'ph','pl','pt','ro','rs','ru','sa','se','sg','si','sk','th','tr','tw','ua','us'
-								
+
 				(str) category - The category you want to get headlines for! Valid values are:
 						'business','entertainment','general','health','science','sports','technology'
-																	
+
         """
 
         # Define Payload
@@ -285,7 +294,7 @@ class NewsApiClient(object):
                 else:
                     raise ValueError('invalid language')
             else:
-                raise TypeError('language param should be a string')
+                raise TypeError('language param should be of type str')
 
         # Country
         if country is not None:
@@ -295,7 +304,7 @@ class NewsApiClient(object):
                 else:
                     raise ValueError('invalid country')
             else:
-                raise TypeError('country param should be a string')
+                raise TypeError('country param should be of type str')
 
                 # Category
         if category is not None:
@@ -305,7 +314,7 @@ class NewsApiClient(object):
                 else:
                     raise ValueError('invalid category')
             else:
-                raise TypeError('category param should be a string')
+                raise TypeError('category param should be of type str')
 
         # Send Request
         r = requests.get(const.SOURCES_URL, auth=self.auth, timeout=30, params=payload)
